import os
import shutil
import torch
import torchvision
from torchvision.datasets import SVHN

DATA_ROOT = 'data'
OUTPUT_DIR = 'datasets/svhn'


def convert_svhn_to_folders(dataset, split='train'):
    for label in range(10):
        label_dir = os.path.join(OUTPUT_DIR, split, str(label))
        os.makedirs(label_dir, exist_ok=True)

    for i in range(len(dataset)):
        img, target = dataset[i]

        if isinstance(img, torch.Tensor):
            img = torchvision.transforms.ToPILImage()(img)

        label_dir = os.path.join(OUTPUT_DIR, split, str(target))
        filename = f"{i}.png"
        save_path = os.path.join(label_dir, filename)

        img.save(save_path)


def prepare_data_svhn():
    train_ds = SVHN(root=DATA_ROOT, split='train', download=True)
    test_ds = SVHN(root=DATA_ROOT, split='test', download=True)

    if os.path.exists(OUTPUT_DIR):
        shutil.rmtree(OUTPUT_DIR)

    convert_svhn_to_folders(train_ds, split='train')
    convert_svhn_to_folders(test_ds, split='test')


if __name__ == "__main__":
    prepare_data_svhn()
